import * as lambda from '@aws-cdk/aws-lambda';
import * as cdk from '@aws-cdk/core';
import * as es from 'esbuild';
/**
 * Properties for a NodejsFunction
 */
export interface NodejsFunctionProps extends lambda.FunctionOptions {
    /**
     * The root of the lambda project. If you specify this prop, ensure that
     * this path includes `entry` and any module/dependencies used by your
     * function otherwise bundling will not be possible.
     *
     * @default = the closest path containing a .git folder
     */
    readonly rootDir?: string;
    /**
     * The name of the method within your code that Lambda calls to execute your function.
     *
     * The format includes the file name and handler function.
     * For more information, see https://docs.aws.amazon.com/lambda/latest/dg/lambda-nodejs.html.
     *
     * @default = 'index.handler'
     */
    readonly handler?: string;
    /**
     * The runtime environment. Only runtimes of the Node.js family are
     * supported.
     *
     * @default = `NODEJS_12_X` if `process.versions.node` >= '12.0.0',
     * `NODEJS_10_X` otherwise.
     */
    readonly runtime?: lambda.Runtime;
    /**
     * The esbuild bundler specific options.
     *
     * @default = { platform: 'node' }
     */
    readonly esbuildOptions?: es.BuildOptions;
}
/**
 * A Node.js Lambda function bundled using `esbuild`
 */
export declare class NodejsFunction extends lambda.Function {
    constructor(scope: cdk.Construct, id: string, props?: NodejsFunctionProps);
}
